diff --git a/dart.module b/dart.module
index 1df42ed..4253024 100644
--- a/dart.module
+++ b/dart.module
@@ -560,7 +560,7 @@ function _dart_get_page_key_vals() {
 function template_preprocess_dart_tag(&$variables) {
   $tag = $variables['tag'];
 
-  $variables['attributes_array']['class'] = 'dart-tag dart-name-' . $tag->machinename;
+  $variables['attr']['class'] = 'dart-tag dart-name-' . $tag->machinename;
   $variables['json_tag'] = drupal_json_encode($tag);
   $variables['load_last']   = variable_get('dart_load_last', '0');
 
@@ -575,6 +575,6 @@ function template_preprocess_dart_tag(&$variables) {
 
   $variables['static_tag'] = l(theme('image', array('path' => $tag->noscript['src'])), $tag->noscript['href'], array('html' => TRUE));
   $variables['noscript_tag'] = $variables['show_noscript_tag'] ? '<noscript>' . $variables['static_tag'] . '</noscript>' : '';
-
+  $variables['foo'] = 'AHHHHHH';
   $variables['tag'] = $tag;
 }
diff --git a/theme/dart_tag.tpl.php b/theme/dart_tag.tpl.php
index a7b0ef6..b9a2e47 100644
--- a/theme/dart_tag.tpl.php
+++ b/theme/dart_tag.tpl.php
@@ -8,7 +8,7 @@
  * - $tag: The full tag object or NULL. If it's NULL, all other
  *         vars listed below will be NULL as well
  * - $json_tag: a js version of $tag.
  * - $attributes: any attributes that should be displayed on the outer-most div.
  * - $show_script_tag: boolean.
  * - $show_noscript_tag: boolean.
  * - $noscript_tag: the <noscript> tag for this DART tag, or empty string.
@@ -17,8 +17,7 @@
  * @see template_preprocess_dart_tag()
  */
 ?>
-
-<div <?php print $attributes; ?>>
+<div <?php print drupal_attributes($attr); ?>>
   <?php if ($tag->slug): ?>
     <span class="slug"><?php print $tag->slug; ?></span>
   <?php endif; ?>
@@ -8,7 +8,7 @@
  *         vars listed below will be NULL as well
  * - $json_tag: a js version of $tag.
- * - $attributes: any attributes that should be displayed on the outer-most div.
+ * - $attr: any attributes that should be displayed on the outer-most div.
  * - $show_script_tag: boolean.
  * - $show_noscript_tag: boolean.
